uncertainties
=============

.. Travis's builds with NumPy had problems: commenting out the Travis part
   image:: https://travis-ci.org/lebigot/uncertainties.png
   :target: https://travis-ci.org/lebigot/uncertainties

This is the uncertainties Python package.

* Documentation: http://pythonhosted.org/uncertainties/
* Python Package Index: http://pypi.python.org/pypi/uncertainties/
* Code: https://github.com/lebigot/uncertainties/
* Issues: https://github.com/lebigot/uncertainties/issues/

GitHub
------

The current version of the ``master*`` branches in the Github
repository are bleeding-edge, but they are *working* versions that
passed the tests for all version of Python starting at 2.4.

The ``master`` branch is for Python 2.5+, while the
``master_python2.3`` branch is for Python 2.3 and 2.4.

Other branches might be present in the GitHub repository, but they are 
temporary and represent work in progress that does not necessarily run 
properly yet.
